This is a demuxer for Matroska (and thus WebM) files, designed to be exactly
sufficient for demuxing the WebM files generated by MediaRecorder, and nothing
else. As a consequence, it's capable of live-demuxing data fed to it and giving
that information back in a semi-useful way, and nothing more.

To use it, create an MkvDemux object, then push ArrayBuffer frames, and call
demux to demux them. For instance:

```javascript
let mkvDemuxer = new mkvdemuxjs.MkvDemux();
let part = null;
mkvDemuxer.push(chunk);
while ((part = mkvDemuxer.demux()) !== null) {
    // Do something with part
}
```

Since it's intended to stream, you can push partial data and push more data
whenever you have it. The `demux` function will return `null` when no new data
is available.

The parts that `demux` returns are in various forms. If it encountered a track
description, it returns an object like so:

```javascript
{
    "track": {
        "number": 1,
        "type": "audio",
        "sampleRate": 48000,
        ... etc ...
    }
}
```

If it encountered a block of frames, it returns an object like so:

```javascript
{
    "frames": [
        {
            timestamp: (in seconds, floating point),
            track: (track number),
            data: (ArrayBuffer)
        }
    ]
}
```

For everything else, it returns an internal representation of the EBML tag,
which is likely not useful.
